@@ -65,10 +65,6 @@ class EntryTypes(dd.Table):
 class Entry(UserAuthored, Controllable, CombinedDateTime,
             Previewable, Publishable):
 
-    """A blog entry is a short article with a title, published on a given
-    date and time by a given user.
-
-    """
     class Meta:
         app_label = 'blogs'
         verbose_name = _("Blog Entry")
@@ -88,10 +84,7 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
         return u'%s #%s' % (self._meta.verbose_name, self.pk)
 
     def on_create(self, ar):
-        """
-        Sets the :attr:`pub_date` and :attr:`pub_time` to now.
-
-        """
+        # Sets the :attr:`pub_date` and :attr:`pub_time` to now.
         if not settings.SITE.loading_from_dump:
             self.set_datetime('pub', timezone.now())
             self.language = ar.get_user().language
