@@ -96,7 +96,7 @@ class MoveEntryNext(dd.MultipleRowAction):
 
 
 class UpdateEntries(dd.MultipleRowAction):
-    label = _('Update Events')
+    label = _('Update events')
     button_text = ' ⚡ '  # 26A1
     # help_text = _('Create or update the automatic calendar entries '
     #               'controlled by this generator.')
@@ -143,28 +143,43 @@ class EventGenerator(dd.Model):
             yield f
         yield "user"
 
-    def delete(self):
-        """Delete all events generated by me before deleting myself."""
+    def disable_delete(self, ar=None):
+        for ee in self.get_existing_auto_events():
+            if ee.is_user_modified():
+                return _("Cannot delete {} because it has user-modified calendar entries.").format(self)
+        return super(EventGenerator, self).disable_delete(ar)
 
-        self.get_existing_auto_events().delete()
+    def delete(self):
+        """
+        Delete all unmodified generated events, including their guests, before
+        deleting self.
+        """
+        # print("20210705 EventGenerator.delete()")
+        for ee in self.get_existing_auto_events():
+            assert not ee.is_user_modified()
+            ee.delete()
         super(EventGenerator, self).delete()
 
-    def update_cal_rset(self):
+    def get_recurrence_set(self):
         raise NotImplementedError()
 
     def update_cal_from(self, ar):
-        """Return the date of the first Event to be generated.
-        Return None if no Events should be generated.
+        """
+
+        Return the date of the first :term:`automatic calendar entry` to be
+        generated.
+
+        Return `None` if no Events should be generated.
 
         """
         return dd.today()
-        # raise NotImplementedError()
-        #~ return self.applies_from
 
     def update_cal_until(self):
-        """Return the limit date until which to generate events.  None means
-        "no limit" (which de facto becomes
-        :attr:`lino_xl.lib.cal.Plugin.ignore_dates_after`)
+        """
+        Return the limit date until which to generate events.
+
+        Returning `None` means "no limit", which de facto becomes
+        :attr:`lino_xl.lib.cal.Plugin.ignore_dates_after`
 
         """
 
@@ -172,9 +187,14 @@ class EventGenerator(dd.Model):
 
     def update_cal_event_type(self):
         """
-        Return the event_type for the events to generate.  Returning None
-        means: don't generate any events.
+
+        Return the :attr:`Event.event_type` for the calendar entries to
+        generate.
+
+        Returning `None` means: don't generate any entries.
+
         """
+        # raise NotImplementedError()
         return None
 
     def get_events_language(self):
@@ -193,7 +213,7 @@ class EventGenerator(dd.Model):
     def get_events_user(self):
         """Returns the user who is responsible for generated events.
 
-        In :mod.`lino_avanti` this is not the author of the course but
+        In :mod:`lino_avanti` this is not the author of the course but
         the teacher.
 
         """
@@ -220,7 +240,7 @@ class EventGenerator(dd.Model):
         if settings.SITE.loading_from_dump:
             #~ print "20111014 loading_from_dump"
             return 0
-        rset = self.update_cal_rset()
+        rset = self.get_recurrence_set()
         wanted, unwanted = self.get_wanted_auto_events(ar)
         # ar.info(
         #     "20171130 get_wanted_auto_events() returned %s, %s",
@@ -237,15 +257,15 @@ class EventGenerator(dd.Model):
 
         # ar.info("%d wanted and %d unwanted events", count, len(unwanted))
 
-        for ee in unwanted.values():
-            if not ee.is_user_modified():
-                ee.delete()
-                count += 1
+        for ee in unwanted:
+            assert not ee.is_user_modified()
+            ee.delete()
+            count += 1
 
         # import pdb ; pdb.set_trace()
 
         # create new Events for remaining wanted
-        for we in wanted.values():
+        for we in wanted:
             if not we.is_user_modified():
                 rset.before_auto_event_save(we)
             we.save()
@@ -257,7 +277,7 @@ class EventGenerator(dd.Model):
         pass
 
     def has_auto_events(self):
-        rset = self.update_cal_rset()
+        rset = self.get_recurrence_set()
         if rset is None:
             # ar.info("No recurrency set")
             return
@@ -270,44 +290,54 @@ class EventGenerator(dd.Model):
         return rset
 
     def get_wanted_auto_events(self, ar=None):
-        wanted = dict()
-        unwanted = dict()
+        existing = dict()
+        wanted = []
+        unwanted = []
         rset = self.has_auto_events()
         if rset is None :
             return wanted, unwanted
 
         qs = self.get_existing_auto_events()
-
         qs = qs.order_by('start_date', 'start_time', 'auto_type')
 
-        # Find the existing event before the first unmodified
-        # event. This is where the algorithm will start.
+        # Find the date and number at which to start generating events.
+        # Find the existing event before the first unmodified event.
+
+        # If the series contains at least one user-modified calendar entry, then
+        # this entry serves as the start point.
+
+        # We reuse existing events to avoid re-creating guests
+
         event_no = 0
-        date = None
+        date = self.update_cal_from(ar)
+        date = rset.find_start_date(date)
         # if qs.count():
         #     raise Exception("20180321 {}".format(qs.count()))
+
+        # loop over existing events in chronological order
         for ee in qs:
-            if ee.is_user_modified():
+            if date is None and ee.is_user_modified():
+                next_date = rset.get_next_suggested_date(ar, ee.start_date)
+                date = next_date
                 event_no = ee.auto_type
-                # date = ee.start_date
-                date = rset.get_next_suggested_date(ar, ee.start_date)
+            if ee.auto_type in existing:
+                # Duplicate auto_type. Keep only one of them.
+                if ee.is_user_modified():
+                    oe = existing[ee.auto_type]
+                    if oe.is_user_modified():
+                        ar.info("Oops: duplicate auto_type {}".format(ee.auto_type))
+                        return wanted, unwanted
+                    unwanted.append(oe)
+                    existing[ee.auto_type] = ee
+                else:
+                    # it's unmodified and duplicate
+                    unwanted.append(ee)
             else:
-                break
-        if event_no is not None:
-            qs = qs.filter(auto_type__gt=event_no)
+                existing[ee.auto_type] = ee
 
         if date is None:
-            date = self.update_cal_from(ar)
-            if not date:
-                ar.info("No start date")
-                return wanted, unwanted
-
-        # Loop over existing events to fill the unwanted dict. In the
-        # beginning all existing events are unwanted. Afterwards we
-        # will pop wanted events from this dict.
-
-        for ee in qs:
-            unwanted[ee.auto_type] = ee
+            ar.info("No start date")
+            return wanted, unwanted
 
         event_type = self.update_cal_event_type()
         if event_type is None:
@@ -337,6 +367,7 @@ class EventGenerator(dd.Model):
         user = self.get_events_user()
         # if max_events is not None and event_no >= max_events:
         #     raise Exception("20180321")
+        last_date = None
         with translation.override(self.get_events_language()):
             while max_events is None or event_no < max_events:
                 if date > until:
@@ -352,8 +383,7 @@ class EventGenerator(dd.Model):
                         auto_type=event_no,
                         user=user,
                         start_date=date,
-                        summary=self.update_cal_summary(
-                            event_type, event_no),
+                        summary=self.update_cal_summary(event_type, event_no),
                         room=self.update_cal_room(event_no),
                         owner=self,
                         event_type=event_type,
@@ -365,25 +395,37 @@ class EventGenerator(dd.Model):
                         ar.info("Could not resolve conflicts for %s",
                                 event_no)
                         return wanted, unwanted
-                    ee = unwanted.pop(event_no, None)
+                    ee = existing.pop(event_no, None)
                     if ee is None:
-                        wanted[event_no] = we
+                        wanted.append(we)
                     elif ee.is_user_modified():
+                        if last_date and ee.start_date < last_date:
+                            msg = _("Automatic entry {} ({}) goes back in time.")
+                            raise Warning(msg.format(ee.auto_type, ee.start_date))
+                        # wanted.append(ee)
                         ar.debug(
                             "%s has been moved from %s to %s."
                             % (ee.summary, date, ee.start_date))
                         date = ee.start_date
                     else:
                         rset.compare_auto_event(ee, we)
-                        # we don't need to add it to wanted because
-                        # compare_auto_event() saves any changes
-                        # immediately.
-                        # wanted[event_no] = we
+                        # we don't need to append it to wanted because
+                        # compare_auto_event() saves any changes immediately.
+
+                last_date = date
                 date = rset.get_next_suggested_date(ar, date)
                 date = rset.find_start_date(date)
                 if date is None:
                     ar.info("Could not find next date after %s.", event_no)
                     break
+
+        # if there is something left in existing, keep only user-modified
+        # entries
+        for ee in existing.values():
+            if ee.is_user_modified():
+                wanted.append(ee)
+            else:
+                unwanted.append(ee)
         return wanted, unwanted
 
     def move_event_next(self, we, ar):
@@ -398,7 +440,7 @@ class EventGenerator(dd.Model):
         def doit(ar):
             if we.state == EntryStates.suggested:
                 we.state = EntryStates.draft
-            rset = self.update_cal_rset()
+            rset = self.get_recurrence_set()
             date = rset.get_next_alt_date(ar, we.start_date)
             if date is None:
                 return
@@ -469,7 +511,7 @@ class EventGenerator(dd.Model):
         return []
 
     def get_date_formatter(self):
-        rset = self.update_cal_rset()
+        rset = self.get_recurrence_set()
         if rset and rset.every_unit:
             return rset.every_unit.get_date_formatter()
         return day_and_month
@@ -818,7 +860,7 @@ class Reservation(RecurrenceSet, EventGenerator, Registrable, UserAuthored):
     def update_cal_until(self):
         return self.max_date
 
-    def update_cal_rset(self):
+    def get_recurrence_set(self):
         """Return the *reccurrency set* to be used when generating events for
         this reservation.
 
@@ -922,6 +964,7 @@ Whether this is private, public or between."""))  # iCal:CLASS
 
     # def get_change_owner(self):
     #     return self.project
+Component.set_widget_options('auto_type', hide_sum=True)
 
 
 #~ Component.owner.verbose_name = _("Automatically created by")
