@@ -337,7 +337,7 @@ class RecurrentEvent(mixins.BabelNamed, RecurrenceSet, EventGenerator,
     # def __unicode__(self):
         # return self.summary
 
-    def update_cal_rset(self):
+    def get_recurrence_set(self):
         return self
 
     def update_cal_from(self, ar):
@@ -412,6 +412,7 @@ class Event(
     event_type = dd.ForeignKey('cal.EventType', blank=True, null=True)
 
     transparent = models.BooleanField(_("Transparent"), default=False)
+    guests_edited = models.BooleanField(default=False)
     room = dd.ForeignKey('cal.Room', null=True, blank=True)
     # priority = dd.ForeignKey(Priority, null=True, blank=True)
     state = EntryStates.field(default='suggested')
@@ -780,21 +781,22 @@ class Event(
 
     def before_state_change(self, ar, old, new):
         super(Event, self).before_state_change(ar, old, new)
-        if new.noauto:
+        if new.noauto:  # cancelling an automatic event disconnexts it from its series.
             self.auto_type = None
+            self.summary = self.summary + " " + _("Cancelled")
         if new.guest_state and self.event_type_id and self.event_type.force_guest_states:
             for obj in self.guest_set.exclude(state=new.guest_state):
                 obj.state = new.guest_state
                 obj.full_clean()
                 obj.save()
 
-    def can_edit_guests_manually(self):
-        # print("20200901", self.state, self.state.fill_guests)
-        if self.state.fill_guests:
-            if self.event_type and self.event_type.fill_presences:
-                return False
-        # print("20200901 yes")
-        return True
+    # def can_edit_guests_manually(self):
+    #     # print("20200901", self.state, self.state.fill_guests)
+    #     if self.state.fill_guests:
+    #         if self.event_type and self.event_type.fill_presences:
+    #             return False
+    #     # print("20200901 yes")
+    #     return True
 
     def suggest_guests(self):
         done = set()
@@ -1098,6 +1100,22 @@ class Guest(Printable):   # TODO: rename the model to "Presence"
     def create_partner_choice(self, text):
         return dd.plugins.cal.partner_model.create_from_choice(text)
 
+    def delete(self, **kw):
+        super(Guest, self).delete(**kw)
+        v = self.event
+        if v.guests_edited:
+            if not v.guest_set.exists():
+                v.guests_edited = False
+                v.save()
+
+    def after_ui_save(self, ar, cw):
+        kw = super(Guest, self).after_ui_save(ar, cw)
+        evt = self.event
+        if evt.owner_id and not evt.guests_edited:
+            evt.guests_edited = True
+            evt.save()
+        return kw
+
 
 def migrate_reminder(obj, reminder_date, reminder_text,
                      delay_value, delay_type, reminder_done):
