@@ -401,28 +401,28 @@ class GuestsByEvent(Guests):
     column_names = 'partner role workflow_buttons remark *'
     order_by = ['partner__name', 'partner__id']
 
-    @classmethod
-    def get_create_permission(cls, ar):
-        if not super(GuestsByEvent, cls).get_create_permission(ar):
-            return False
-        mi = ar.master_instance
-        if mi and mi.can_edit_guests_manually():
-            return  True
-        return False
+    # @classmethod
+    # def get_create_permission(cls, ar):
+    #     if not super(GuestsByEvent, cls).get_create_permission(ar):
+    #         return False
+    #     mi = ar.master_instance
+    #     if mi and mi.can_edit_guests_manually():
+    #         return  True
+    #     return False
 
-    @classmethod
-    def disable_delete(cls, obj, ar):
-        msg = super(GuestsByEvent, cls).disable_delete(obj, ar)
-        if msg is not None:
-            return msg
-        mi = ar.master_instance
-        if mi is None:
-            raise Exception("You must specify a master instance")
-        # assert mi == obj.event
-        if mi.can_edit_guests_manually():
-            return None
-        # return _("Guests are filled automatically.")
-        return _("Cannot edit guests manually.")
+    # @classmethod
+    # def disable_delete(cls, obj, ar):
+    #     msg = super(GuestsByEvent, cls).disable_delete(obj, ar)
+    #     if msg is not None:
+    #         return msg
+    #     mi = ar.master_instance
+    #     if mi is None:
+    #         raise Exception("You must specify a master instance")
+    #     # assert mi == obj.event
+    #     if mi.can_edit_guests_manually():
+    #         return None
+    #     # return _("Guests are filled automatically.")
+    #     return _("Cannot edit guests manually.")
 
 
 
