@@ -6,14 +6,6 @@
 
 See :doc:`/specs/courses`.
 
-.. autosummary::
-   :toctree:
-
-   models
-   mixins
-   choicelists
-   workflows
-
 """
 
 from django.utils.text import format_lazy
