@@ -281,8 +281,9 @@ class Course(Reservation, Duplicable, Printable):
         return self.start_date
 
     def update_cal_event_type(self):
-        if self.line_id:
+        if self.line_id and self.line.event_type_id:
             return self.line.event_type
+        return settings.SITE.site_config.default_event_type
 
     def update_cal_summary(self, et, i):
         if self.every_unit == Recurrencies.once:
@@ -630,6 +631,7 @@ class Enrolment(UserAuthored, Certifiable, DateRange):
 
     def make_guest_for(self, event):
         if not self.state.uses_a_place:
+            # print("20210707 not self.state.uses_a_place", event)
             return
         gr = self.get_guest_role()
         if gr is not None:
