@@ -1,6 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2017 Luc Saffre
-#
+# Copyright 2011-2017 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -16,15 +15,12 @@ import logging ; logger = logging.getLogger(__name__)
 import datetime
 
 from django.conf import settings
-import six
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 from lino.api import dd, rt
 from lino.core import constants
-
-from lino.modlib.office.roles import OfficeUser
 from lino.utils import join_elems
-
+from lino.modlib.office.roles import OfficeUser
 from lino_xl.lib.cal.models import Calendars, Events
 
 
@@ -39,6 +35,7 @@ class CalendarAction(dd.Action):
     action_name = 'grid'  # because...
     default_format = 'html'
     icon_name = 'calendar'
+    window_type = constants.WINDOW_TYPE_TABLE
 
 
 class ExtDateTimeField(dd.VirtualField):
@@ -81,7 +78,7 @@ class ExtSummaryField(dd.VirtualField):
 
     def set_value_in_object(self, request, obj, value):
         if obj.project:
-            s = six.text_type(obj.project)
+            s = str(obj.project)
             if value.startswith(s):
                 value = value[len(s):]
         obj.summary = value
@@ -132,7 +129,7 @@ class PanelCalendars(Calendars):
     @dd.displayfield()
     def summary(cls, self, ar):
         #~ return dd.babelattr(self,'name')
-        return six.text_type(self)
+        return str(self)
 
     @dd.virtualfield(models.BooleanField(_('Hidden')))
     def is_hidden(cls, self, ar):
@@ -169,7 +166,7 @@ class PanelEvents(Events):
         for t in super(PanelEvents, self).get_title_tags(ar):
             yield t
         if ar.subst_user:
-            yield six.text_type(ar.subst_user)
+            yield str(ar.subst_user)
 
     @classmethod
     def parse_req(self, request, rqdata, **kw):
