@@ -220,8 +220,7 @@ class VoucherType(dd.Choice):
         return self.model.items.rel.related_model
 
     def get_items_table(self):
-        lh = self.table_class.detail_layout.get_layout_handle(
-            settings.SITE.kernel.default_ui)
+        lh = self.table_class.detail_layout.get_layout_handle()
         from lino.modlib.extjs.elems import GridElement
         for e in lh.walk():
             # print(repr(e), e.__class__)
