@@ -22,6 +22,7 @@ from lino.modlib.printing.mixins import PrintableType
 from lino.modlib.system.choicelists import ObservedEvent
 from lino.modlib.uploads.mixins import UploadController
 from lino.modlib.users.mixins import UserAuthored
+from lino.core.keyboard import Hotkey
 from lino.core.fields import TableRow
 from lino.utils import SumCollector
 from lino.utils import mti
@@ -805,7 +806,7 @@ class Voucher(UserAuthored, Duplicable, UploadController, PeriodRangeObservable)
             return self.journal.uploads_volume
 
 
-Voucher.set_widget_options('number_with_year', width=8)
+Voucher.set_widget_options('number_with_year', width=10)
 # Voucher.set_widget_options('number', hide_sum=True)
 
 
@@ -816,6 +817,7 @@ class ToggleState(dd.Action):
     label = _("Toggle state")
     # action_name = "changemystate"
     button_text = "⏼" # 23FC Toggle power
+    hotkey = Hotkey('x', ctrl=True)
 
     def run_from_ui(self, ar, **kw):
         obj = ar.selected_rows[0]
@@ -850,13 +852,6 @@ class RegistrableVoucher(Registrable, Voucher):
             return "{0} #{1}".format(self.journal.ref, self.id)
         return super(RegistrableVoucher, self).__str__()
 
-    @classmethod
-    def get_actions_hotkeys(cls):
-        return [{'key': 'x',
-                'ctrl': True,
-                'shift': False,
-                'ba': 'toggle_state'}]
-
     def after_state_change(self, ar, oldstate, newstate):
         # Movements are created *after* having changed the state because
         # otherwise the match isn't correct.
