@@ -175,7 +175,7 @@ class Order(Certifiable, RegistrableVoucher, RecurrenceSet, EventGenerator, Dupl
             yield f
         yield 'name'
 
-    def update_cal_rset(self):
+    def get_recurrence_set(self):
         return self
 
     def update_cal_from(self, ar):
