@@ -713,9 +713,20 @@ class MyTickets(My, Tickets):
     order_by = ["priority", "-id"]
     column_names = "priority detail_link assigned_to planned_time SUMMARY_FIELDS workflow_buttons *"
     params_panel_hidden = True
+    # params_layout = """
+    # user end_user site #project state #priority
+    # start_date end_date observed_event #topic #feasable_by show_active"""
     params_layout = """
-    user end_user site #project state #priority
-    start_date end_date observed_event #topic #feasable_by show_active"""
+    end_user
+    site
+    state
+    start_date
+    end_date
+    observed_event
+    show_active
+    user
+    """
+    params_panel_pos = "left"
 
     @classmethod
     def param_defaults(self, ar, **kw):
@@ -866,7 +877,7 @@ class SitesByGroup(Sites):
 
 
 class MySites(Sites):
-    label = _("My sites")
+    label = _("My projects")
     column_names = "detail_link parsed_description workflow_buttons *"
 
     @classmethod
