@@ -24,7 +24,7 @@ from lino.mixins.periods import ObservedDateRange
 from lino_xl.lib.tickets.roles import Triager, TicketsStaff
 from lino_xl.lib.tickets.choicelists import (
     TicketEvents, TicketStates)
-from lino_xl.lib.calview.ui import Day, EventsParameters, DayNavigator, DaySlave, DaysTable
+from lino_xl.lib.calview.ui import Day, ParameterClone, DayNavigator, DaySlave, DaysTable
 
 from .roles import Worker
 from .choicelists import ReportingTypes
@@ -668,8 +668,8 @@ class SummariesByUser(UserSummaries):
 
 # class WorkedHours(Days, dd.VentilatingTable):
 # class WorkedHours(CalendarView):
-# class WorkedHours(EventsParameters, DayNavigator, dd.VentilatingTable):
-class WorkedHours(EventsParameters, DaysTable, dd.VentilatingTable):
+# class WorkedHours(ParameterClone, DayNavigator, dd.VentilatingTable):
+class WorkedHours(ParameterClone, DaysTable, dd.VentilatingTable):
     label = _("Worked hours")
     # column_names_template = 'day_number long_date detail_link description {vcolumns}'
     column_names_template = 'detail_link worked_tickets {vcolumns} *'
